/*******************************************************************************************/
/*                                File rpcap.x                                             */
/*                                                                                         */
/*           Copyright (C) S. Krishnan <sri_krishnan@yahoo.com>, 2002                      */
/*                                                                                         */
/*     The RPCGEN input file for the rpcap Remote Packet Capture library                   */
/*     language: RPC Language (Sun RPC)                                                    */
/*     Compiler: rpcgen                                                                    */
/*     Dependencies: None                                                                  */
/*******************************************************************************************/
 
 
/*
 * This file is part of the RPCAP Remote Packet Capture System.
 *
 * RPCAP is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * It is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 
 * You should have received a copy of the GNU General Public License along
 * with this program; see the file COPYING.  If not, write to
 * the Free Software Foundation, 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA.
 */


/*
 * Changelog:
 *
 * Version 0.1: 1/02/2002 - basic capture functionality OK
 * lots of API implementation work to be done: pcap_lookup*, pcap_datalink, pcap_stats, pcap_close
 *
 * Version 0.2: 5/02/2002 - API extended with pcap_datalink, pcap_lookup*, pcap_close, etc
 *
 * Version 0.25: 18/02/2002: fixes so that rpcap_client gets the server's errbuf buffer contents
 *                           added rpcap_strerror function
 *
 */



struct adapter_handle
{
   opaque adapter_pcap<1024>;                            /* the pcap_t data */
	/* string ebuf<>; */
};
typedef struct adapter_handle adapter_handle;

struct bpf_prg
{
	opaque bpf_prgrm<1024>;					/* the bpf program struct */
};
typedef struct bpf_prg bpf_prg;

struct rpcap_func_rtn
{
	int retval;
	string ebuf<>;
};
typedef struct rpcap_func_rtn rpcap_func_rtn;
typedef rpcap_func_rtn * RPCAP_FN_RTN_PTR;


struct cl_addr
{
    u_long cl_ip;
    u_short cl_port;
};

/* the parameters for pcap_open_live */

struct rpcap_open_live_params
{
    string device<>;
    int snaplen;
    int promisc;
    int to_ms;
	/* string ebuf<>; */
};

typedef struct rpcap_open_live_params RPCAP_OPEN_LIVE_PARAMS;

struct rpcap_lookupnet_params
{
    string device<>;
    string errbuf<>;
};
typedef struct rpcap_lookupnet_params RPCAP_LOOKUPNET_PARAMS;

struct rpcap_lookupnet_result
{
   int lookupnet_ret_val;
   u_int netp;
   u_int maskp;
	string ebuf<>;
};

typedef rpcap_lookupnet_result RPCAP_LOOKUPNET_RESULT;
typedef RPCAP_LOOKUPNET_RESULT* LOOKUPNET_RESULT_PTR;

struct rpcap_capture_params
{
    adapter_handle *p;
    int cnt;
    struct cl_addr client_address;	/* the TCP port through which we will receive callback data */
    u_int cap_func_sel;			/* to select from pcap_dispatch or pcap_loop */
};
typedef struct rpcap_capture_params RPCAP_CAPTURE_PARAMS;


struct rpcap_compile_params
{
    adapter_handle *p;
    string str<>;
    int optimize;
    u_int netmask;
};
typedef struct rpcap_compile_params RPCAP_COMPILE_PARAMS;

struct rpcap_setfilter_params
{
    adapter_handle *p;
    bpf_prg *fp;
};
typedef struct rpcap_setfilter_params RPCAP_SETFILTER_PARAMS;

typedef adapter_handle* adapter_ptr;

typedef struct bpf_prg * BPF_PRG_PTR;

struct rpcap_stats_wrapper
{
    opaque pcap_stats<256>;	/* at present the struct has only 3 u_ints, so this should be OK */
    int stats_retval;           /* the value returned by the function call */
};

typedef struct rpcap_stats_wrapper RPCAP_STATS_WRAPPER;
typedef RPCAP_STATS_WRAPPER* STATS_WRAPPER_PTR;

typedef char target_adapter;
typedef target_adapter* TARGET_ADAPTER;
typedef TARGET_ADAPTER* ADAPTER_PTR;
/* typedef *target_adapter TARGET_ADAPTER; */


struct rpcap_error
{
	string pcap_error<>;
	int rpcap_err_retval;
};

typedef struct rpcap_error RPCAP_ERROR;	
typedef RPCAP_ERROR *RPCAP_ERROR_PTR;

program RPCAP
{
   version RPCAPVER
	{
		/* adapter_ptr rpcap_open_live(RPCAP_OPEN_LIVE_PARAMS open_params) = 1; */
		adapter_ptr  rpcap_open_live(RPCAP_OPEN_LIVE_PARAMS open_params) = 1;
	   	RPCAP_FN_RTN_PTR rpcap_lookupdev() = 2;
	   	/* LOOKUPNET_RESULT_PTR rpcap_lookupnet(RPCAP_LOOKUPNET_PARAMS lookup_params) = 3; */
		LOOKUPNET_RESULT_PTR rpcap_lookupnet(string device<>) = 3;
	   	int rpcap_capture(RPCAP_CAPTURE_PARAMS cap_params) = 4;
	   	BPF_PRG_PTR rpcap_compile(RPCAP_COMPILE_PARAMS compile_params) = 5;
	   	int rpcap_setfilter(RPCAP_SETFILTER_PARAMS filtparams) = 6;
	   	int rpcap_datalink(adapter_handle* p) = 7;
	   	int rpcap_snapshot(adapter_handle*  p) = 8;
	  	 int rpcap_close(adapter_handle *p) = 9;
	   	STATS_WRAPPER_PTR rpcap_stats(adapter_handle *p) = 10;
		RPCAP_FN_RTN_PTR rpcap_geterr(adapter_handle *p) = 11;
		/* string rpcap_strerror(int error) = 12; */
		int rpcap_end_capture() = 12;
	 } = 1;
} = 0x20000001;




